summaryrefslogtreecommitdiff
path: root/plugins/FTPFileYM/curl/lib/imap.h
diff options
context:
space:
mode:
authorGeorge Hazan <george.hazan@gmail.com>2013-11-10 21:43:18 +0000
committerGeorge Hazan <george.hazan@gmail.com>2013-11-10 21:43:18 +0000
commit530102b3b16fdc6f008cdf312e5977a878f295db (patch)
tree3159eb3d5712151a33d796b7a0039ae9a4d00e09 /plugins/FTPFileYM/curl/lib/imap.h
parente40ecc70a7db28bdf78dad5d804e07d08a77159c (diff)
libcurl update
git-svn-id: http://svn.miranda-ng.org/main/trunk@6864 1316c22d-e87f-b044-9b9b-93d7a3e3ba9c
Diffstat (limited to 'plugins/FTPFileYM/curl/lib/imap.h')
-rw-r--r--plugins/FTPFileYM/curl/lib/imap.h43
1 files changed, 33 insertions, 10 deletions
diff --git a/plugins/FTPFileYM/curl/lib/imap.h b/plugins/FTPFileYM/curl/lib/imap.h
index b37cdab839..1d4faabd70 100644
--- a/plugins/FTPFileYM/curl/lib/imap.h
+++ b/plugins/FTPFileYM/curl/lib/imap.h
@@ -31,10 +31,10 @@ typedef enum {
IMAP_STOP, /* do nothing state, stops the state machine */
IMAP_SERVERGREET, /* waiting for the initial greeting immediately after
a connect */
+ IMAP_CAPABILITY,
IMAP_STARTTLS,
IMAP_UPGRADETLS, /* asynchronously upgrade the connection to SSL/TLS
(multi mode only) */
- IMAP_CAPABILITY,
IMAP_AUTHENTICATE_PLAIN,
IMAP_AUTHENTICATE_LOGIN,
IMAP_AUTHENTICATE_LOGIN_PASSWD,
@@ -43,26 +43,49 @@ typedef enum {
IMAP_AUTHENTICATE_DIGESTMD5_RESP,
IMAP_AUTHENTICATE_NTLM,
IMAP_AUTHENTICATE_NTLM_TYPE2MSG,
- IMAP_AUTHENTICATE,
+ IMAP_AUTHENTICATE_XOAUTH2,
+ IMAP_AUTHENTICATE_FINAL,
IMAP_LOGIN,
+ IMAP_LIST,
IMAP_SELECT,
IMAP_FETCH,
+ IMAP_FETCH_FINAL,
+ IMAP_APPEND,
+ IMAP_APPEND_FINAL,
IMAP_LOGOUT,
IMAP_LAST /* never used */
} imapstate;
+/* This IMAP struct is used in the SessionHandle. All IMAP data that is
+ connection-oriented must be in imap_conn to properly deal with the fact that
+ perhaps the SessionHandle is changed between the times the connection is
+ used. */
+struct IMAP {
+ curl_pp_transfer transfer;
+ char *mailbox; /* Mailbox to select */
+ char *uidvalidity; /* UIDVALIDITY to check in select */
+ char *uid; /* Message UID to fetch */
+ char *section; /* Message SECTION to fetch */
+ char *custom; /* Custom request */
+ char *custom_params; /* Parameters for the custom request */
+};
+
/* imap_conn is used for struct connection-oriented data in the connectdata
struct */
struct imap_conn {
struct pingpong pp;
- char *mailbox; /* Mailbox to select */
- unsigned int authmechs; /* Accepted authentication mechanisms */
- unsigned int authused; /* Auth mechanism used for the connection */
- imapstate state; /* Always use imap.c:state() to change state! */
- int cmdid; /* Next command ID */
- const char *idstr; /* String based response ID to wait for */
- bool ssldone; /* Is connect() over SSL done? */
- bool login_disabled; /* LOGIN command explicitly disabled by server */
+ imapstate state; /* Always use imap.c:state() to change state! */
+ bool ssldone; /* Is connect() over SSL done? */
+ unsigned int authmechs; /* Accepted authentication mechanisms */
+ unsigned int prefmech; /* Preferred authentication mechanism */
+ unsigned int authused; /* Auth mechanism used for the connection */
+ int cmdid; /* Last used command ID */
+ char resptag[5]; /* Response tag to wait for */
+ bool tls_supported; /* StartTLS capability supported by server */
+ bool login_disabled; /* LOGIN command disabled by server */
+ bool ir_supported; /* Initial response supported by server */
+ char *mailbox; /* The last selected mailbox */
+ char *mailbox_uidvalidity; /* UIDVALIDITY parsed from select response */
};
extern const struct Curl_handler Curl_handler_imap;